class Weightlifting

  # MEN:
  #   A = 0.751945030
  #   b = 175.508 kg
  #
  def self.sinclair_coeff_male(bodyweight_kg)
    sinclair(bodyweight_kg, 0.751945030, 175.508)
  end

  # WOMEN:
  #   A = 0.783497476
  #   b = 153.655 kg
  def self.sinclair_coeff_female(bodyweight_kg)
    sinclair(bodyweight_kg, 0.783497476, 153.655)
  end

  # Values for men are:
  # a=-216.0475144
  # b=16.2606339
  # c=-0.002388645
  # d=-0.00113732
  # e=7.01863E-06
  # f=-1.291E-08
  def self.wilks_coeff_male(bodyweight_kg)
    wilks(bodyweight_kg, -216.0475144, 16.2606339, -0.002388645, -0.00113732, 0.00000701863, -0.00000001291)
  end

  # Value for women are:
  # a=594.31747775582
  # b=-27.23842536447
  # c=0.82112226871
  # d=-0.00930733913
  # e=4.731582E-05
  # f=-9.054E-08
  def self.wilks_coeff_female(bodyweight_kg)
    wilks(bodyweight_kg, 594.31747775582, -27.23842536447, 0.82112226871, -0.00930733913, 0.00004731582, -0.00000009054)
  end

  def self.pounds_to_kilos(pounds)
    pounds / 2.20462262185
  end

  def self.kilos_to_pounds(kilos)
    kilos * 2.20462262185
  end

  private
    # https://en.wikipedia.org/wiki/Sinclair_Coefficients
    # Sinclair Coefficient = 10^(-AX^2) and X = log_10(x/b)
    # x = Athletes bodyweight (kilograms)
    def self.sinclair(bodyweight, a, b)
      if (bodyweight >= b)
        1.0
      end
      @coefficient = 10**(a * (Math::log10(bodyweight/b)**2))
    end

    # https://en.wikipedia.org/wiki/Wilks_Coefficient
    # 500 / (a + bx^2 + cx^3 + dx^4 + ex^5 + fx^6)
    # x = Athletes bodyweight (kilograms)
    def self.wilks(bodyweight, a, b, c, d, e, f)
      500 / (a + (b * bodyweight) + (c * bodyweight**2) + (d * bodyweight**3) + (e * bodyweight**4) + (f * bodyweight**5))
    end
end
